@@ -22,7 +22,7 @@
 #'    \item MAPE is "unstable when \eqn{X_i} values are near zero", and
 #'    \item "If X and Y are interchanged, the MAPE will result in a
 #'      different value."
-#'}
+#' }
 #'
 #'
 #' @param predicted numeric vector that contains the predicted data
@@ -38,12 +38,12 @@
 #'
 #'
 #'
-#' @source
-#' r - Better error message for stopifnot? - Stack Overflow answered by Andrie on Dec 1 2011. See \url{https://stackoverflow.com/questions/8343509/better-error-message-for-stopifnot}.
+#'
+#'
 #'
 #'
 #' @references
-#' Lei Ji and Kevin Gallo, "An Agreement Coefficient for Image Comparison", \emph{Photogrammetric Engineering & Remote Sensing}, Vol. 72, No. 7, July 2006, p. 823-8335, \url{http://www.ingentaconnect.com/content/asprs/pers/2006/00000072/00000007/art00006}.
+#' Lei Ji and Kevin Gallo, "An Agreement Coefficient for Image Comparison", \emph{Photogrammetric Engineering & Remote Sensing}, Vol. 72, No. 7, July 2006, p. 823-8335, \url{https://www.ingentaconnect.com/content/asprs/pers/2006/00000072/00000007/art00006}.
 #'
 #' @encoding UTF-8
 #'
@@ -69,7 +69,7 @@
 #' mape(pre, obs)
 #'
 #'
-#' require("stats")
+#' library("stats")
 #' set.seed(100) # makes the example reproducible
 #' obs1 <- rnorm(100) # observed
 #' pre1 <- rnorm(100) # predicted
@@ -107,6 +107,9 @@
 #'
 #'
 #'
+#' @import checkmate
+#' @import assertthat
+#'
 #' @export
 mape <- function (predicted, observed, na.rm = FALSE) {
 
@@ -116,31 +119,18 @@ mape <- function (predicted, observed, na.rm = FALSE) {
 # The moments::kurtosis code has been helpful with regards to the treatment of
 # na.rm
 
-if (length(predicted) < 1 | length(observed) < 1) {
+assert_that(!any(qtest(predicted, "N>1(-Inf,Inf)") == FALSE), msg = "predicted is Inf, -Inf, a string, empty Or contains less than 1 value or 1 value only. Please try again.")
+# only process with finite values and provide a stop warning if not
 
-  stop("Check the length of the predicted and observed vectors since one of
-  them has a length of 0. Use a different set of values and then try again.")
+assert_that(!any(qtest(observed, "N>1(-Inf,Inf)") == FALSE), msg = "observed is Inf, -Inf, a string, empty Or contains less less than 1 value or 1 value only. Please try again.")
+# only process with finite values and provide a stop warning if not
+
+assert_that(((any(observed) == 0) == FALSE), msg = "observed is 0. Use a different set of values and then try again.")
 # Source 1 / provide a stop warning if the length of one of the vectors is 0
 
-} else {
+assert_that(((length(predicted) != length(observed)) == FALSE), msg = "Check the length of the predicted and observed vectors since they don't match. Use a different set of values and then try again.")
+# Source 1 / provide a stop warning if the length of the numeric vectors do not match
 
-if (length(predicted) != length(observed)) {
-
-  stop("Check the length of the predicted and observed vectors since they
-  don't match. Use a different set of values and then try again.")
-# Source 1 / provide a stop warning if the length of the numeric vectors do
-# not match
-
-} else {
-
-if (!is.numeric(predicted) | !is.numeric(observed)) {
-
-  stop("Either the predicted or observed vector is not numeric. Use a different
-  set of values and then try again.")
-# Source 1 / provide a stop warning if the either one of the vectors is not
-# numeric
-
-} else {
 
 if (na.rm == TRUE) {
 
@@ -160,6 +150,3 @@ if (na.rm == TRUE) {
 
 }
 }
-}
-}
-}
